==> org-lsst-ccs-ui-2.4.8-sources.jar: org/lsst/ccs/gconsole/plugins/tracer/filters/HeartBeatSelector.java <==
package org.lsst.ccs.gconsole.plugins.tracer.filters;

import java.util.Arrays;
import org.lsst.ccs.gconsole.plugins.tracer.FilteredMessage;
import org.lsst.ccs.gconsole.plugins.tracer.MessageFilter;
import org.lsst.ccs.gconsole.plugins.tracer.MessageFilterFactory;

/**
 * Filter that selects or rejects heartbeat status messages.
 *
 * @author onoprien
 */
public class HeartBeatSelector implements MessageFilterFactory {

    @Override
    public String getDescription() {
        return "Filter that selects or rejects heartbeat status messages.<p>"
                + "<b>Optional parameters:</b>"
                + "<dl>"
                + "<dt>invert</dt><dd>If checked, heartbeats are accepted and all other messages rejected.</dd>"
                + "</dl>";
    }

    @Override
    public String getPath() {
        return "BuiltIn/Remove HeartBeat";
    }

    @Override
    public String getName() {
        return "HeartBeat Selector";
    }

    @Override
    public MessageFilter get(String[] parameters) {
        if (parameters == null || parameters.length != 1) throw new IllegalArgumentException("Illegal parameters: "+ Arrays.toString(parameters));
        return new Filter("true".equalsIgnoreCase(parameters[0]));
    }
    
    public MessageFilter getInstance(boolean invert) {
        return new Filter(invert);
    }
    
    
    private class Filter extends AbstractMessageFilter {

        private final boolean invert;

        public Filter(boolean invert) {
            this.invert = invert;
        }

        @Override
        public FilteredMessage test(FilteredMessage filteredMessage) {
            boolean accept = filteredMessage.getBusMessage().getClass().getName().contains("StatusHeartBeat");
            return invert ^ accept ? filteredMessage : null;
        }

        @Override
        public String getDescription() {
            return HeartBeatSelector.this.getDescription();
        }

        @Override
        public String getPath() {
            return HeartBeatSelector.this.getPath();
        }

        @Override
        public String getName() {
            return HeartBeatSelector.this.getName();
    }

    }
    
}

==> org-lsst-ccs-ui-3.5.0-sources.jar: org/lsst/ccs/gconsole/plugins/tracer/filters/HeartBeatSelector.java <==
package org.lsst.ccs.gconsole.plugins.tracer.filters;

import org.lsst.ccs.gconsole.plugins.tracer.FilteredMessage;
import org.lsst.ccs.gconsole.plugins.tracer.MessageFilter;
import org.lsst.ccs.gconsole.plugins.tracer.MessageFilterFactory;

/**
 * Filter that selects or rejects heartbeat status messages.
 *
 * @author onoprien
 */
public class HeartBeatSelector implements MessageFilterFactory {

    @Override
    public String getDescription() {
        return "Filter that rejects heartbeat status messages.<p>";
    }

    @Override
    public String getPath() {
        return "BuiltIn/Remove HeartBeat";
    }

    @Override
    public String getName() {
        return "HeartBeat Remover";
    }

    @Override
    public MessageFilter get(String[] parameters) {
        return new Filter();
    }
    
    public MessageFilter getInstance() {
        return new Filter();
    }
    
    
    private class Filter extends AbstractMessageFilter {

        @Override
        public FilteredMessage test(FilteredMessage filteredMessage) {
            boolean isHeartBeat = filteredMessage.getBusMessage().getClass().getName().contains("StatusHeartBeat");
            return isHeartBeat ? null : filteredMessage;
        }

        @Override
        public String getDescription() {
            return HeartBeatSelector.this.getDescription();
        }

        @Override
        public String getPath() {
            return HeartBeatSelector.this.getPath();
        }

        @Override
        public String getName() {
            return HeartBeatSelector.this.getName();
    }

    }
    
}
